@@ -95,6 +95,8 @@ wxStringToStringHashMap gs_msgIdCharset;
 // Platform specific helpers
 // ----------------------------------------------------------------------------
 
+#if wxUSE_LOG_TRACE
+
 void LogTraceArray(const char *prefix, const wxArrayString& arr)
 {
     wxLogTrace(TRACE_I18N, "%s: [%s]", prefix, wxJoin(arr, ','));
@@ -107,6 +109,13 @@ void LogTraceLargeArray(const wxString& prefix, const wxArrayString& arr)
         wxLogTrace(TRACE_I18N, "    %s", *i);
 }
 
+#else // !wxUSE_LOG_TRACE
+
+#define LogTraceArray(prefix, arr)
+#define LogTraceLargeArray(prefix, arr)
+
+#endif // wxUSE_LOG_TRACE/!wxUSE_LOG_TRACE
+
 // Use locale-based detection as a fallback
 wxString GetPreferredUILanguageFallback(const wxArrayString& WXUNUSED(available))
 {
@@ -180,6 +189,8 @@ wxString GetPreferredUILanguage(const wxArrayString& available)
 
 #elif defined(__WXOSX__)
 
+#if wxUSE_LOG_TRACE
+
 void LogTraceArray(const char *prefix, CFArrayRef arr)
 {
     wxString s;
@@ -193,6 +204,8 @@ void LogTraceArray(const char *prefix, CFArrayRef arr)
     wxLogTrace(TRACE_I18N, "%s: [%s]", prefix, s);
 }
 
+#endif // wxUSE_LOG_TRACE
+
 wxString GetPreferredUILanguage(const wxArrayString& available)
 {
     wxStringToStringHashMap availableNormalized;
